<?php
/**
 * Get option the user configured for contratPlus 0, 1 or 2
 *
 * @param   Database        $db             The object given by dolibarr global (global $db)
 * @return  string                          null on error, option configured on success
 */
function getOption($db)
{
    $sql = "SELECT llx_contratplus.active FROM llx_contratplus WHERE llx_contratplus.name = 'OPTION'";
    $resql = $db->query($sql);
    $res = $resql->fetch_assoc();
    return $res['active'];
}

/**
 * Check if user have authorisation in function of the option
 *
 * @param   int             $option         option of contrat plus
 * @param   User            $user           user to check authorisation
 * @return  bool                            true if user have, false if he doesn't
 */
function isAuthorize($option, $user)
{
    $rights = false;

    switch ($option)
    {
        case 0:
            if ($user->rights->contrat->lire && $user->rights->contrat->creer
                && $user->rights->contrat->activer && $user->rights->contrat->desactiver)
                $rights = true;

            break;
        case 1:
            if ($user->rights->contrat->lire && $user->rights->contrat->creer
                && $user->rights->contrat->activer && $user->rights->contrat->desactiver
                && $user->rights->facture->lire && $user->rights->facture->creer)
                $rights = true;

            break;
        case 2:
            if ($user->rights->contrat->lire && $user->rights->contrat->creer
                && $user->rights->contrat->activer && $user->rights->contrat->desactiver
                && $user->rights->facture->lire && $user->rights->facture->creer
                && $user->rights->facture->invoice_advance->validate)
                $rights = true;

            break;
        default:
            $rights = true;
            break;
    }

    return $rights;
}

/**
 * Check if contract $id is a supplier contract
 *
 * @param   Database        $db             The object given by dolibarr global (global $db)
 * @param   int             $id             Id of the contract
 * @return  bool                            false if contract is not a supplier contract, true if it is
 */
function isSupplierContract($db, $id)
{
    $sql = "SELECT ce.supplier_contract FROM llx_contrat_extrafields AS ce WHERE ce.fk_object = " . $id;
    $resql = $db->query($sql);
    $res = $resql->fetch_assoc();
    return $res['supplier_contract'] == null ? false : true;
}

/**
 * Calculate the due date for the invoice payment
 *
 * @param   CommonObject    $object     The object to process (an invoice if you are in invoice module, a propale in propale's module, etc...)
 * @param   Database        $db         The object given by dolibarr global (global $db)
 * @return  string
 */
function getDateLim($object, $db)
{
    if ($object->cond_reglement_id == "") $object->cond_reglement_id = 1;

    $sql = "SELECT llx_c_payment_term.nbjour FROM llx_c_payment_term WHERE llx_c_payment_term.rowid = ".$object->cond_reglement_id;
    dol_syslog($sql, LOG_DEBUG);
    $res = $db->query($sql);
    $nb = $res->fetch_assoc();

    return $nb != null ? date(strtotime('Y-m-d',$object->date.' + '.$nb['nbjour'].' days')) : dol_now();
}
