<?php
/* Copyright (C) 2001-2004 Rodolphe Quiedeville <rodolphe@quiedeville.org>
 * Copyright (C) 2004-2016 Laurent Destailleur  <eldy@users.sourceforge.net>
 * Copyright (C) 2005-2012 Regis Houssin        <regis.houssin@capnetworks.com>
 * Copyright (C) 2015      Jean-François Ferry	<jfefe@aternatik.fr>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

/**
 *	    \file       htdocs/contrat/services.php
 *      \ingroup    contrat
 *		\brief      Page to list services in contracts
 */

$res=0;
if (! $res && file_exists("../main.inc.php")) $res=@include("../main.inc.php");         // to work if your module directory is into dolibarr root htdocs directory
if (! $res && file_exists("../../main.inc.php")) $res=@include("../../main.inc.php");       // to work if your module directory is into a subdir of root htdocs directory
require_once (DOL_DOCUMENT_ROOT."/contrat/class/contrat.class.php");
require_once (DOL_DOCUMENT_ROOT."/product/class/product.class.php");
require_once (DOL_DOCUMENT_ROOT."/societe/class/societe.class.php");

require_once DOL_DOCUMENT_ROOT.'/core/class/html.formother.class.php';
require_once DOL_DOCUMENT_ROOT . '/core/class/extrafields.class.php';
require_once 'core/function.php';

$langs->load("products");
$langs->load("contracts");
$langs->load("companies");

$mode = GETPOST("mode");
$sortfield = GETPOST("sortfield",'alpha');
$sortorder = GETPOST("sortorder",'alpha');
$page = GETPOST("page",'int');
if (!$page) { $page = 0 ; }
$limit = GETPOST('limit')?GETPOST('limit','int'):$conf->liste_limit;
$offset = $limit * $page ;

if (! $sortfield) $sortfield="c.rowid";
if (! $sortorder) $sortorder="ASC";

$filter=GETPOST("filter");
$search_name=GETPOST("search_name");
$search_contract=GETPOST("search_contract");
$search_service=GETPOST("search_service");
$search_status=GETPOST("search_status","alpha");
$search_price=GETPOST("search_price");
$statut=GETPOST('statut')?GETPOST('statut'):1;
$socid=GETPOST('socid','int');

$opouvertureprevuemonth=(GETPOST('dateouvertureprevuemonth')!='00'?GETPOST('dateouvertureprevuemonth'):'01');
$opouvertureprevueday=(GETPOST('dateouvertureprevueday')!='00'?GETPOST('dateouvertureprevueday'):'01');
$opouvertureprevueyear=(GETPOST('dateouvertureprevueyear')!='00'?GETPOST('dateouvertureprevueyear'):'1990');
$filter_opouvertureprevue=GETPOST('filter_opouvertureprevue');

$options_serv_duree=GETPOST('options_serv_duree');

$opclotureprevuemonth=(GETPOST('dateclotureprevuemonth')!='00'?GETPOST('dateclotureprevuemonth'):'01');
$opclotureprevueday=(GETPOST('dateclotureprevueday')!='00'?GETPOST('dateclotureprevueday'):'01');
$opclotureprevueyear=(GETPOST('dateclotureprevueyear')!='00'?GETPOST('dateclotureprevueyear'):'1990');
$filter_opclotureprevue=GETPOST('filter_opclotureprevue');

$opcloturemonth=GETPOST('opcloturemonth');
$opclotureday=GETPOST('opclotureday');
$opclotureyear=GETPOST('opclotureyear');
$filter_opdateEnd=GETPOST('filter_opdateEnd');

if(GETPOST('search_cli_four')!='') $search_cli_four=GETPOST('search_cli_four');
else $search_cli_four=-1;
$search_product_category=GETPOST('search_product_category','int');

// Security check
$contratid = GETPOST('id','int');
if (! empty($user->societe_id)) $socid=$user->societe_id;
$result = restrictedArea($user, 'contrat',$contratid);

if ($search_status != '')
{
    $tmp=explode('&', $search_status);
    $mode=$tmp[0];
    if (empty($tmp[1])) $filter='';
    else
    {
        if ($tmp[1] == 'filter=notexpired') $filter='notexpired';
        if ($tmp[1] == 'filter=expired') $filter='expired';
    }
}
else
{
    $search_status = $mode;
    if ($filter == 'expired') $search_status.='&filter=expired';
    if ($filter == 'notexpired') $search_status.='&filter=notexpired';
}

$contextpage='contractlist';

// Initialize technical object to manage hooks of thirdparties. Note that conf->hooks_modules contains array array
$hookmanager->initHooks(array($contextpage));

/*
 * Action
 */

if (GETPOST("button_removefilter_x") || GETPOST("button_removefilter.x") || GETPOST("button_removefilter")) // All test are required to be compatible with all browsers
{
	$search_name="";
	$search_contract="";
	$search_service="";
	$search_status=-1;
	$search_price="";
	
	$opouvertureprevuemonth="";
	$opouvertureprevueday="";
	$opouvertureprevueyear="";
	$filter_opouvertureprevue="";

	$options_serv_duree="";

    $opclotureprevuemonth="";
    $opclotureprevueday="";
    $opclotureprevueyear="";
    $filter_opclotureprevue="";

	$opcloturemonth="";
	$opclotureday="";
	$opclotureyear="";
	$filter_opdateEnd="";

	$mode='';
	$filter='';
	$search_cli_four='-1';
	$search_product_category='';
	$subprice='';
}

/*
 * View
 */

$now=dol_now();

$companystatic=new Societe($db);
$form=new Form($db);
$formother = new FormOther($db);

$extrafield = new ExtraFields($db);
// fetch optionals attributes and labels

		// $extrafields = new ExtraFields($db);
		// $extralabels=$extrafields->fetch_name_optionals_label('contrat');

		// $extrafieldsline = new ExtraFields($db);
		// $extralabelslines=$extrafieldsline->fetch_name_optionals_label('contratdet');

$extralabels = $extrafield->fetch_name_optionals_label('contratdet');
// $search_array_options=$extrafield->getOptionalsFromPost($extralabels,'','search_');

llxHeader();

$filter_dateouvertureprevue=$opouvertureprevueyear.'-'.sprintf("%02d", $opouvertureprevuemonth).'-'.sprintf("%02d", $opouvertureprevueday);
$filter_dateclotureprevue=$opclotureprevueyear.'-'.sprintf("%02d", $opclotureprevuemonth).'-'.sprintf("%02d", $opclotureprevueday);
$filter_datecloture=$opclotureyear.'-'.sprintf("%02d", $opcloturemonth).'-'.sprintf("%02d", $opclotureday).' 00:00:00';

$sql = "SELECT c.rowid as cid, c.ref, c.statut as cstatut,";
$sql.= " s.rowid as socid, s.nom as name, s.fournisseur,";
$sql.= " cd.rowid, cd.description, cd.statut, cd.subprice as price, ";
$sql.= " p.rowid as pid, p.ref as pref, p.label as label, p.fk_product_type as ptype, p.entity as pentity,";
if (!$user->rights->societe->client->voir && !$socid) $sql .= " sc.fk_soc, sc.fk_user,";
$sql.= " cd.date_fin_validite,";
$sql.= " cd.date_cloture,";
$sql.= " ca.color as color";

// Add fields from extrafields
foreach ($extrafield->attribute_label as $key => $val) $sql.=($extrafield->attribute_type[$key] != 'separate' ? ",ef.".$key.' as options_'.$key : '');

// if (! empty($filter_opdateEnd) && $filter_opdateEnd != -1 && $filter_datecloture != '') 
	// $sql.= ", DATE_ADD(ef.serv_date_start,INTERVAL ef.serv_duree MONTH) as DATE_MIN";

$sql.= " FROM ".MAIN_DB_PREFIX."contrat as c,";
$sql.= " ".MAIN_DB_PREFIX."societe as s,";
if (!$user->rights->societe->client->voir && !$socid) $sql .= " ".MAIN_DB_PREFIX."societe_commerciaux as sc,";
$sql.= " ".MAIN_DB_PREFIX."contratdet as cd";
if (is_array($extrafield->attribute_label) && count($extrafield->attribute_label)) $sql.= " LEFT JOIN ".MAIN_DB_PREFIX."contratdet_extrafields as ef on (cd.rowid = ef.fk_object)";
$sql.= " LEFT JOIN ".MAIN_DB_PREFIX."product as p ON cd.fk_product = p.rowid";
$sql.= ' LEFT JOIN '.MAIN_DB_PREFIX.'categorie_product as cp ON cp.fk_product=cd.fk_product';
$sql.= ' LEFT JOIN '.MAIN_DB_PREFIX.'categorie as ca ON ca.rowid=cp.fk_categorie';

// Add where from extra fields
// foreach ($search_array_options as $key => $val)
// {
//     $crit=$val;
//     $tmpkey=preg_replace('/search_options_/','',$key);
//     $typ=$extrafields->attribute_type[$tmpkey];
//     $mode=0;
//     if (in_array($typ, array('int','double'))) $mode=1;    // Search on a numeric
//     if ($val && ( ($crit != '' && ! in_array($typ, array('select'))) || ! empty($crit))) 
//     {
//         $sql .= natural_search('ef.'.$tmpkey, $crit, $mode);
//     }
// }
// Add where from hooks

$sql.= " WHERE c.entity = ".$conf->entity;
$sql.= " AND c.rowid = cd.fk_contrat";
$sql.= " AND c.fk_soc = s.rowid";
if (!$user->rights->societe->client->voir && !$socid) $sql .= " AND s.rowid = sc.fk_soc AND sc.fk_user = " .$user->id;
if ($search_product_category > 0) $sql.=" AND cp.fk_categorie = ".$search_product_category;
if ($mode == "0") $sql.= " AND cd.statut = 0";
if ($mode == "4") $sql.= " AND cd.statut = 4";
if ($mode == "5") $sql.= " AND cd.statut = 5";
if ($filter == "expired") $sql.= " AND cd.date_fin_validite < '".$db->idate($now)."'";
if ($filter == "notexpired") $sql.= " AND cd.date_fin_validite >= '".$db->idate($now)."'";
if ($search_name)     $sql.= " AND s.nom LIKE '%".$db->escape($search_name)."%'";
if ($search_cli_four != '-1')     $sql .= " AND s.fournisseur = ".$search_cli_four;
if ($search_contract) $sql.= " AND c.ref LIKE '%".$db->escape($search_contract)."%'";
if ($search_service)  $sql.= " AND (p.ref LIKE '%".$db->escape($search_service)."%' OR p.description LIKE '%".$db->escape($search_service)."%' OR cd.description LIKE '%".$db->escape($search_service)."%')";
if ($socid > 0)       $sql.= " AND s.rowid = ".$socid;
if ($search_price) $sql.= " AND cd.subprice >= ".$search_price;
if ($options_serv_duree) $sql.= " AND ef.serv_duree = '".$options_serv_duree."'";

if (! empty($filter_opouvertureprevue) && $filter_opouvertureprevue != -1 && $filter_dateouvertureprevue != '') $sql.= " AND ef.serv_date_start ".$filter_opouvertureprevue." '".$filter_dateouvertureprevue."'";
if (! empty($filter_opclotureprevue) && $filter_opclotureprevue != -1 && $filter_dateclotureprevue != '') $sql.= " AND ef.serv_date_end ".$filter_opclotureprevue." '".$filter_dateclotureprevue."'";
if (! empty($filter_opdateEnd) && $filter_opdateEnd != -1 && $filter_datecloture != '') $sql.= " AND cd.date_fin_validite ".$filter_opdateEnd." DATE_MIN ";
//if (! empty($filter_opdateEnd) && $filter_opdateEnd != -1 && $filter_datecloture != '') $sql.= " AND cd.date_cloture ".$filter_opdateEnd." '".$db->idate($filter_datecloture)."'";

$totalnboflines=0;
$result=$db->query($sql);
if ($result)
{
    $totalnboflines = $db->num_rows($result);
}

$sql .= $db->order($sortfield, $sortorder);

$sql .= $db->plimit($limit + 1, $offset);

dol_syslog("contrat/services.php", LOG_DEBUG);
$resql=$db->query($sql);
if ($resql)
{
	$num = $db->num_rows($resql);
	$i = 0;

	$param='';
	if ($search_contract) $param.='&amp;search_contract='.urlencode($search_contract);
	if ($search_name)      $param.='&amp;search_name='.urlencode($search_name);
	if ($search_service)  $param.='&amp;search_service='.urlencode($search_service);
	if ($mode)            $param.='&amp;mode='.$mode;
	if ($filter)          $param.='&amp;filter='.$filter;

    if (! empty($filter_opouvertureprevue) && $filter_opouvertureprevue != -1) $param.='&amp;filter_opouvertureprevue='.urlencode($filter_opouvertureprevue);
    if (! empty($filter_opclotureprevue) && $filter_opclotureprevue != -1) $param.='&amp;filter_opclotureprevue='.urlencode($filter_opclotureprevue);
	if (! empty($filter_opdateEnd) && $filter_opdateEnd != -1) $param.='&amp;filter_opdateEnd='.urlencode($filter_opdateEnd);

    if ($filter_dateouvertureprevue != '')  $param.='&amp;dateouvertureprevueday='.sprintf("%02d", $opouvertureprevueday).'&amp;dateouvertureprevuemonth='.sprintf("%02d", $opouvertureprevuemonth).'&amp;dateouvertureprevueyear='.sprintf("%02d", $opouvertureprevueyear);
    if ($filter_dateclotureprevue != '')  $param.='&amp;dateclotureprevueday='.sprintf("%02d", $opclotureprevueday).'&amp;dateclotureprevuemonth='.sprintf("%02d", $opclotureprevuemonth).'&amp;dateclotureprevueyear='.sprintf("%02d", $opclotureprevueyear);
	if ($filter_datecloture != '') $param.='&amp;opclotureday='.$opclotureday.'&amp;opcloturemonth='.$opcloturemonth.'&amp;opclotureyear='.$opclotureyear;

	if ($search_cli_four != '-1') $param.='&amp;search_cli_four='.$search_cli_four;

	if($search_price) $param.='&amp;search_price='.$search_price;

	if($options_serv_duree) $param.='&amp;options_serv_duree='.$options_serv_duree;

    if ($search_product_category) $param .= '&amp;search_product_category=' . $search_product_category;

    $title=$langs->trans("Contratplus_ServicePlus");

	if ($mode == "0") $title=$langs->trans("ListOfInactiveServices");	// Must use == "0"
	if ($mode == "4" && $filter != "expired") $title=$langs->trans("ListOfRunningServices");
	if ($mode == "4" && $filter == "expired") $title=$langs->trans("ListOfExpiredServices");
	if ($mode == "5") $title=$langs->trans("ListOfClosedServices");

    print '<form method="POST" action="'. $_SERVER["PHP_SELF"] .'">';
	print '<input type="hidden" name="token" value="'.$_SESSION['newtoken'].'">';

	print_barre_liste($title, $page, $_SERVER["PHP_SELF"], $param, $sortfield, $sortorder,'',$num,$totalnboflines,'object_contract.png',0, '', '', $limit);

    // DEBUG
    if($conf->global->MAIN_FEATURES_LEVEL=='3') {
        print '<table class="noborder tagtable liste listwithfilterbefore" width="100%">';
        print '<tr><td><h2>DEBUG</h2></td></tr>';
        print '<tr><td><b>SQL : </b>'.$sql.'</td></tr>';
        print '<tr><td><b>PARAM : </b>'.$param.'</td></tr>';
        print '</table>';
    }

	    // If the user can view prospects other than his'
    $moreforfilter='';
    // Filtre Client / Fournisseur
    if ($user->rights->societe->client->voir & $user->rights->fournisseur->lire)
    {
        $moreforfilter.='<div class="divsearchfield">';
        $moreforfilter.=$langs->trans('ServiceAllClientFournisseur');
        $moreforfilter.=' <select class="flat minwidth100 maxwidth300" id="search_cli_four" name="search_cli_four">
        <option value="-1" '.($search_cli_four=="-1"?"selected":"").'>'.$langs->trans('All').'</option>
        <option value="0" '.($search_cli_four=="0"?"selected":"").'>'.$langs->trans('Client').'</option>
        <option value="1" '.($search_cli_four=="1"?"selected":"").'>'.$langs->trans('Fournisseur').'</option>
        </select>';
        $moreforfilter.='</div>';
    }

	// If the user can view categories of products
    if ($conf->categorie->enabled && ($user->rights->produit->lire || $user->rights->service->lire))
    {
        include_once DOL_DOCUMENT_ROOT.'/categories/class/categorie.class.php';
        $moreforfilter.='<div class="divsearchfield">';
        $moreforfilter.=$langs->trans('IncludingProductWithTag'). ': ';
        $cate_arbo = $form->select_all_categories(Categorie::TYPE_PRODUCT, null, 'parent', null, null, 1);
        $moreforfilter.=$form->selectarray('search_product_category', $cate_arbo, $search_product_category, 1, 0, 0, '', 0, 0, 0, 0, '', 1);
        $moreforfilter.='</div>';
    }
    

    $parameters=array();
    $reshook=$hookmanager->executeHooks('printFieldPreListTitle',$parameters);    // Note that $action and $object may have been modified by hook
	if (empty($reshook)) $moreforfilter .= $hookmanager->resPrint;
	else $moreforfilter = $hookmanager->resPrint;
    if (! empty($moreforfilter))
    {
        print '<div class="liste_titre liste_titre_bydiv centpercent">';
        print $moreforfilter;
        print '</div>';
    }

	print '<table class="noborder tagtable liste listwithfilterbefore" width="100%">';

	print '<tr class="liste_titre">';
	print_liste_field_titre('');
    print_liste_field_titre('');
	print_liste_field_titre($langs->trans("Contract"),$_SERVER["PHP_SELF"], "c.rowid",$param,"",'',$sortfield,$sortorder);
	print_liste_field_titre($langs->trans("Service"),$_SERVER["PHP_SELF"], "p.description",$param,"","",$sortfield,$sortorder);
	print_liste_field_titre($langs->trans("Company"),$_SERVER["PHP_SELF"], "s.nom",$param,"","",$sortfield,$sortorder);
	print_liste_field_titre($langs->trans("ContratplusDateStart"),$_SERVER["PHP_SELF"], "ef.serv_date_start",$param,'',' align="center"',$sortfield,$sortorder);
	print_liste_field_titre($langs->trans("ContratplusEngage"),$_SERVER["PHP_SELF"], "ef.serv_duree",$param,'',' align="center"',$sortfield,$sortorder);
    print_liste_field_titre($langs->trans("ContratplusDateEnd"),$_SERVER["PHP_SELF"], "ef.serv_date_end",$param,'',' align="center"',$sortfield,$sortorder);
	print_liste_field_titre($langs->trans("Price"),$_SERVER["PHP_SELF"], "cd.subprice",$param,'','align="center" width="120"',$sortfield,$sortorder);
	print_liste_field_titre($langs->trans("Status"),$_SERVER["PHP_SELF"], "cd.statut,c.statut",$param,'','align="right"',$sortfield,$sortorder);
	print_liste_field_titre('');
	print "</tr>\n";

	print '<input type="hidden" name="filter" value="'.$filter.'">';
	print '<input type="hidden" name="mode" value="'.$mode.'">';
	print '<tr class="liste_titre_sel">';
	print '<td class="liste_titre">&nbsp;</td>';
    print '<td class="liste_titre">&nbsp;</td>';
	print '<td class="liste_titre">';
	print '<input type="text" class="flat" size="15" name="search_contract" value="'.dol_escape_htmltag($search_contract).'">';
	print '</td>';
	// Service label
	print '<td class="liste_titre">';
	print '<input type="text" class="flat" size="20" name="search_service" value="'.dol_escape_htmltag($search_service).'">';
	print '</td>';
	// Third party
	print '<td class="liste_titre">';
	print '<input type="text" class="flat" size="20" name="search_name" value="'.dol_escape_htmltag($search_name).'">';
	print '</td>';

	//Date debut
    print '<td class="liste_titre" align="center" style=" width: 200px;">';
    $arrayofoperators=array('<'=>'<','>'=>'>');
    print $form->selectarray('filter_opouvertureprevue',$arrayofoperators,$filter_opouvertureprevue,1);
    print ' ';
    $filter_dateouvertureprevue=dol_mktime(0,0,0,$opouvertureprevuemonth,$opouvertureprevueday,$opouvertureprevueyear);
    print $form->select_date($filter_dateouvertureprevue,'dateouvertureprevue',0,0,1,'',1,0,1);
    print '</td>';

	// Service duree
	print '<td class="liste_titre" align="center" style=" width: 220px;">';
	print $extrafield->showInputField('serv_duree',$options_serv_duree);

	print '&nbsp;</td>';

	// Date cloture
    print '<td class="liste_titre" align="center" style=" width: 200px;">';
    $arrayofoperators=array('<'=>'<','>'=>'>');
    print $form->selectarray('filter_opclotureprevue',$arrayofoperators,$filter_opclotureprevue,1);
    print ' ';
    $filter_dateclotureprevue=dol_mktime(0,0,0,$opclotureprevuemonth,$opclotureprevueday,$opclotureprevueyear);
    print $form->select_date($filter_dateclotureprevue,'dateclotureprevue',0,0,1,'',1,0,1);
    print '</td>';

	// Service Price
	print '<td align="center">';
	print '<input type="text" class="flat" size="6" name="search_price" value="'.dol_escape_htmltag($search_price).'">';
	print '</td>';

	// Service Status
	print '<td align="right">';
	$arrayofstatus=array(
	    '0'=>$langs->trans("ServiceStatusInitial"),
	    '4'=>$langs->trans("ServiceStatusRunning"),
	    '4&filter=notexpired'=>$langs->trans("ServiceStatusNotLate"),
	    '4&filter=expired'=>$langs->trans("ServiceStatusLate"),
	    '5'=>$langs->trans("ServiceStatusClosed")
	);
	print $form->selectarray('search_status',$arrayofstatus,(strstr($search_status, ',')?-1:$search_status),1);
	print '</td>';

	print '<td class="liste_titre" align="right">';
	$searchpitco=$form->showFilterAndCheckAddButtons(0);
	print $searchpitco;
	print '</td>';
    print "</tr>\n";

	$var=true;
	while ($i < min($num,$limit))
	{
		$obj = $db->fetch_object($resql);
		
		$contractstatic=new Contrat($db);
		$staticcontratligne=new ContratLigne($db);
		$productstatic=new Product($db);
		$extrafields = new ExtraFields($db);
		$extrafieldsline = new ExtraFields($db);

		$contractstatic->id=$obj->cid;
		$contractstatic->ref=$obj->ref?$obj->ref:$obj->cid;
		$staticcontratligne->id=$obj->rowid;

		$staticcontratligne->fetch($obj->rowid);
		$extralabels=$extrafields->fetch_name_optionals_label('contrat');
		$extralabelslines=$extrafieldsline->fetch_name_optionals_label('contratdet');

		$contractstatic->fetch_optionals($contractstatic->id,$extralabels);
		$staticcontratligne->fetch_optionals($staticcontratligne->rowid,$extralabelslines);

		$var=!$var;

		print "<tr ".$bc[$var];
		if($obj->fournisseur=="1") print ' style="font-style: italic ; background-color: #'.$obj->color.'"';
		print ">";
		
		//Color
		if($obj->fournisseur=="0") print '<td style=" background-color: #'.$obj->color.'">';
		else print '<td>';
		print '&nbsp;</td>';

        if (isSupplierContract($db, $contractstatic->id)) {
            print '<td>' . img_object($langs->trans('SupplierContract'),"sending") . '</td>';
        }
        else {
            print '<td>' . img_object($langs->trans('CustomerContract'),"user") . '</td>';
        }

		// Ref
		print '<td>';
		print $contractstatic->getNomUrl(1,16);
		print '</td>';

		// Service
		print '<td>';
		if ($obj->pid)
		{
			$productstatic->id=$obj->pid;
			$productstatic->type=$obj->ptype;
			$productstatic->ref=$obj->pref;
			$productstatic->entity=$obj->pentity;
			print $productstatic->getNomUrl(1,'',24);
            print $obj->label?' - '.dol_trunc($obj->label):'';
            if (! empty($obj->description) && ! empty($conf->global->PRODUCT_DESC_IN_LIST)) print '<br>'.dol_nl2br($obj->description);
		}
		else
		{
			if ($obj->type == 0) print img_object($obj->description,'product').' '.dol_trunc($obj->description,24);
			if ($obj->type == 1) print img_object($obj->description,'service').' '.dol_trunc($obj->description,24);
		}
		print '</td>';

		// Third party
		print '<td>';
		$companystatic->id=$obj->socid;
		$companystatic->name=$obj->name;
		$companystatic->client=1;
		print $companystatic->getNomUrl(1,'customer',28);
		print '</td>';

		// ContratplusDateStart

		    print '<td align="center">';

		    if($obj->options_serv_date_start!="0000-00-00")
		        print dol_print_date($staticcontratligne->array_options['options_serv_date_start']);

            $obj->options_serv_date_start=='';
            print '</td>';


		// ContratplusEngage
	    print '<td align="center">';
	    print $extrafieldsline->attribute_param['serv_duree']['options'][intval($staticcontratligne->array_options['options_serv_duree'])];
	    print '</td>';

		// ContratplusDateEnd

        print '<td align="center">';

        if($obj->options_serv_date_end!="0000-00-00")
            print dol_print_date($staticcontratligne->array_options['options_serv_date_end']);

        $obj->options_serv_date_end == '';
        print '</td>';

		// Icone warning
		print '</td>';
		// Service price
		print '<td align="center">';
		if(isset($obj->price)) print price($obj->price).' €'; else print '&nbsp';
		print '</td>';

		print '<td align="right" class="nowrap">';
		if ($obj->cstatut == 0)	// If contract is draft, we say line is also draft
		{
			print $contractstatic->LibStatut(0,5,($obj->date_fin_validite && $db->jdate($obj->date_fin_validite) < $now));
		}
		else
		{
			print $staticcontratligne->LibStatut($obj->statut,5,($obj->date_fin_validite && $db->jdate($obj->date_fin_validite) < $now)?1:0);
		}
		print '</td>';

		print '<td></td>';
		print "</tr>\n";
		$i++;
	}
	$db->free($resql);

	print '</table></form>';

}
else
{
	dol_print_error($db);
}


llxFooter();

$db->close();
